@@ -14,7 +14,7 @@ Supported Libaries
 ==================
 
 ``wsgi_intercept`` works with a variety of HTTP clients in Python 2.7,
-3.5 and beyond, and in pypy.
+3.7 and beyond, and in pypy.
 
 * urllib2
 * urllib.request
@@ -22,7 +22,7 @@ Supported Libaries
 * http.client
 * httplib2
 * requests
-* urllib3
+* urllib3 (<2.0.0, urllib3 2 support is in progress)
 
 How Does It Work?
 =================
@@ -88,7 +88,7 @@ Packages Intercepted
 Unfortunately each of the HTTP client libraries use their own specific
 mechanism for making HTTP call-outs, so individual implementations are
 needed. At this time there are implementations for ``httplib2``,
-``urllib3`` and ``requests`` in both Python 2 and 3, ``urllib2`` and
+``urllib3`` (<2.0.0) and ``requests`` in both Python 2 and 3, ``urllib2`` and
 ``httplib`` in Python 2 and ``urllib.request`` and ``http.client``
 in Python 3.
 
@@ -115,7 +115,7 @@ it into all of the *other* Python Web testing frameworks.
 The Python 2 version of wsgi-intercept was the result. Kumar McMillan
 later took over maintenance.
 
-The current version is tested with Python 2.7, 3.5-3.8, and pypy and pypy3.
+The current version is tested with Python 2.7, 3.5-3.11, and pypy and pypy3.
 It was assembled by `Chris Dent`_. Testing and documentation improvements
 from `Sasha Hart`_.
 
@@ -260,7 +260,7 @@ def make_environ(inp, host, port, script_name):
         else:
             h = k.upper()
             h = h.replace(b'-', b'_')
-            environ['HTTP_' + h.decode('ISO-8859-1')] = v
+            environ['HTTP_' + str(h.decode('ISO-8859-1'))] = v
 
         if debuglevel >= 2:
             print('HEADER:', k, v)
